@@ -82,13 +82,12 @@ bool FunctionGraphFactory::registerFunctionGraph(Dimension dim, PlotItemConstuct
         const QString& iconNameFunction, ExamplesFunction examplesFunction)
 {
     QStringList arguments(_arguments);
-    qSort(arguments);
-    
+    std::sort(arguments.begin(), arguments.end());
+
+    //TODO: turn this id into an internal struct
     QString id = QString::number((int)dim)+"|"+
                  QString::number((int)coordinateSystemFunction)+"|"+
                  arguments.join(QStringLiteral(","));
-                 
-                
     Q_ASSERT(!contains(id)); // verificar que no se registren los mismos tipos
 
     typeNameFunctions[id] = typeNameFunction;
@@ -108,7 +107,7 @@ QString FunctionGraphFactory::trait(const Analitza::Expression& expr, const Anal
 {
     Q_ASSERT(!expr.isEquation());
     QStringList args = expr.bvarList();
-    qSort(args);
+    std::sort(args.begin(), args.end());
 
     QString key;
     for (int i = 0; i < argumentsFunctions.values().size() && key.isEmpty(); ++i) {
